# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,boids_simulation)
S3method(as_ggwebgl_spec,boids_simulation)
S3method(ggWebGL::as_ggwebgl_spec,boids_simulation)
export(as_ggwebgl_spec)
export(boids_params)
export(boids_scenario)
export(boids_state)
export(boids_world)
export(simulate_boids)
importFrom(Rcpp,sourceCpp)
useDynLib(boids4R, .registration = TRUE)
